@@ -7,7 +7,7 @@ use Clustericious::Log;
 use base 'Mojolicious::Controller';
 
 # ABSTRACT: Clustericious controller base class
-our $VERSION = '0.9938'; # VERSION
+our $VERSION = '0.9939'; # VERSION
 
 
 sub url_for {
@@ -55,10 +55,13 @@ sub redirect_to {
 sub render_not_found {
     my $self = shift;
     undef $self->stash->{autodata} if exists($self->stash->{autodata});
-    $self->SUPER::render_not_found(@_);
+    $self->helpers->reply->not_found
 }
 
 
+sub render_exception { shift->helpers->reply->exception(@_) }
+
+
 sub render_text { shift->render( text => @_ ) };
 sub render_json { shift->render( json => @_ ) };
 
@@ -74,7 +77,7 @@ Clustericious::Controller - Clustericious controller base class
 
 =head1 VERSION
 
-version 0.9938
+version 0.9939
 
 =head1 SYNOPSIS
 
@@ -109,6 +112,10 @@ the location header.
 
 Clustericious version of this method usually provided by Mojolicious.
 
+=head2 $c-E<gt>render_exception($message)
+
+Clustericious version of this method usually provided by Mojolicious.
+
 =head2 $c-E<gt>render_text
 
 Previous versions of Mojolicious included this
